import QtQuick 2.7
import AppControls 1.0
import AppStyle 1.0
import AppDialogs 1.0

Item {
    id: zOffsetMenu
    property real zOffset: printerModel.zOffsetStep.toFixed(2)

    Component.onCompleted: {
        rootItem.hideHead()
    }

    Connections {
        target: printerModel
        onOn_zOffset: {
            print("on_zoffset")
            zoffsetColumn.visible = true
        }
    }

    ConfirmDialog {
        id: proceedConfirm
        z: 105
        anchors.centerIn: parent
        visible: true
        titleText: "Warning"
        titleColor: AppStyle.orange
        msg: qsTr("Printer will now home and move to X250 Y100.\nAre you sure you want to proceed?")
        yesText: qsTr("Proceed")
        noText: qsTr("Back")
        onYes: {
            printerModel.startZoffsetCalibration()
        }
        onNo: {
            rootItem.showHead()
            rootItem.back()
        }
    }

    Item {
        anchors {
            top: parent.top
            right: parent.right
            left: parent.left
            bottom: footer.top
        }

        Column {
            id: zoffsetWaitColumn
            anchors.centerIn: parent
            width: parent.width
            visible: !zoffsetColumn.visible
            spacing: AppStyle.defaultMargin

            Item {
                width: zoffsetWaitColumn.width
                height: waitIndicator.height
                AppBusyIndicator {
                    id: waitIndicator
                    anchors.centerIn: parent
                }
            }

            Text {
                width: zoffsetWaitColumn.width
                horizontalAlignment: Text.AlignHCenter
                color: AppStyle.textColor
                text: qsTr("Moving to calibration point...")
                font {
                    bold: true
                    pixelSize: 25
                }
            }
        }

        Column {
            id: zoffsetColumn
            anchors.centerIn: parent
            visible: false
            spacing: AppStyle.defaultMargin
            Text {
                id: zOffsetLabel
                width: zOffsetSpinBox.width
                height: zOffsetLabel.paintedHeight
                horizontalAlignment: Text.AlignHCenter
                color: AppStyle.textColor
                text: qsTr("Calibration probe Z offset\nPlease use arrow buttons\nto set the gap between the nozzle and the build plate.\nMake sure that the nozzle tip slightly touches the build plate.\nPress Save when done.")
                font {
                    bold: true
                    pixelSize: 25
                }
            }

            AppVertSpinBox {
                id: zOffsetSpinBox
                value: printerModel.zOffset
                onUpPressed: {
                    printerModel.moveZOneStepUp()
                }
                onDownPressed: {
                    printerModel.moveZOneStepDown()
                }
            }
        }
    }

    Footer {
        id: footer
        anchors {
            bottom: parent.bottom
            right: parent.right
            left: parent.left
        }

        nextBtnText: qsTr("Save")
        nextBtnVisible: true
        onBackClicked: {
            printerModel.executeGcodeLine("G90")
            rootItem.showHead()
            rootItem.back()
        }

        onNextClicked: {
            printerModel.zOffset = zOffsetSpinBox.value.toFixed(2)
            rootItem.showHead()
            rootItem.hideSetting()
        }
    }
}
